==> ejc-probuilddiary-impl-3.0.0-20220916.071534-5-sources.jar: com/ejianc/business/probuilddiary/person/bean/PersonTypeEntity.java <==
package com.ejianc.business.probuilddiary.person.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人日志-施工组织设计、方案、交底、变更情况（技术负责人）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_person_type")
public class PersonTypeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="person_id")
    private Long personId; // 个人日志id
    @TableField(value="work_type_id")
    private Long workTypeId; // 工作类别id
    @TableField(value="work_type_name")
    private String workTypeName; // 工作类别名称
    @TableField(value="work_type_code")
    private String workTypeCode; // 工作类别编码
    @TableField(value="work_type_memo")
    private String workTypeMemo; // 工作描述
    
    
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public Long getWorkTypeId() {
        return workTypeId;
    }

    public void setWorkTypeId(Long workTypeId) {
        this.workTypeId = workTypeId;
    }
    public String getWorkTypeName() {
        return workTypeName;
    }

    public void setWorkTypeName(String workTypeName) {
        this.workTypeName = workTypeName;
    }
    public String getWorkTypeCode() {
        return workTypeCode;
    }

    public void setWorkTypeCode(String workTypeCode) {
        this.workTypeCode = workTypeCode;
    }
    public String getWorkTypeMemo() {
        return workTypeMemo;
    }

    public void setWorkTypeMemo(String workTypeMemo) {
        this.workTypeMemo = workTypeMemo;
    }
    
}

==> ejc-probuilddiary-impl-3.0.0-20220919.071841-10-sources.jar: com/ejianc/business/probuilddiary/person/bean/PersonTypeEntity.java <==
package com.ejianc.business.probuilddiary.person.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人日志-施工组织设计、方案、交底、变更情况（技术负责人）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_person_type")
public class PersonTypeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="person_id")
    private Long personId; // 个人日志id
    @TableField(value="work_type_id")
    private Long workTypeId; // 工作类别id
    @TableField(value="work_type_name")
    private String workTypeName; // 工作类别名称
    @TableField(value="work_type_code")
    private String workTypeCode; // 工作类别编码
    @TableField(value="work_type_memo")
    private String workTypeMemo; // 工作描述
    @TableField(value = "file_type")
    private String fileType; // 文件类型


    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }
    
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public Long getWorkTypeId() {
        return workTypeId;
    }

    public void setWorkTypeId(Long workTypeId) {
        this.workTypeId = workTypeId;
    }
    public String getWorkTypeName() {
        return workTypeName;
    }

    public void setWorkTypeName(String workTypeName) {
        this.workTypeName = workTypeName;
    }
    public String getWorkTypeCode() {
        return workTypeCode;
    }

    public void setWorkTypeCode(String workTypeCode) {
        this.workTypeCode = workTypeCode;
    }
    public String getWorkTypeMemo() {
        return workTypeMemo;
    }

    public void setWorkTypeMemo(String workTypeMemo) {
        this.workTypeMemo = workTypeMemo;
    }
    
}
